@@ -1,6 +1,6 @@
 # !/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from typing import List
+from typing import List, Union
 
 from ._utils import event_class
 
@@ -12,6 +12,7 @@ class Model:
     GUILDS - 频道事件
     GUILD_MEMBERS -
     """
+
     class GUILDS(event_class):
         """
         频道事件的数据模型，可从t字段判断具体事件，其中包含：
@@ -24,6 +25,7 @@ class Model:
             其子字段数据可参阅：
             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#guilds
         """
+
         description: str
         icon: str
         id: str
@@ -48,6 +50,7 @@ class Model:
             其子字段数据可参阅：
             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#channels-sdkv2-2-4
         """
+
         application_id: str
         guild_id: str
         id: str
@@ -76,6 +79,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#guild-members
         """
+
         class user:
             avatar: str
             bot: bool
@@ -104,6 +108,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message
         """
+
         class __MsgMentions:
             avatar: str
             bot: bool
@@ -146,7 +151,7 @@ class Model:
         pinned: bool
         type: int
         flags: int
-        treated_msg: str
+        treated_msg: Union[str, tuple]
         t: str
         event_id: str
 
@@ -165,6 +170,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message-delete
         """
+
         class message:
             class author:
                 bot: bool
@@ -191,6 +197,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#direct-message
         """
+
         class __MsgAttachments:
             content_type: str
             filename: str
@@ -239,6 +246,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message-audit
         """
+
         audit_id: str
         audit_time: str
         create_time: str
@@ -297,24 +305,24 @@ class Model:
                         class text:  # type = 1
                             text: str
 
-#                         class image:  # type = 2
-#                             class plat_image:
-#                                 url: str
-#                                 width: int
-#                                 height: int
-#                                 image_id: str
-#
-#                         class video:  # type = 3
-#                             class plat_video:
-#                                 class cover:
-#                                     url: str
-#                                     width: int
-#                                     height: int
-#
-#                                 url: str
-#                                 width: int
-#                                 height: int
-#                                 video_id: str
+                        #                         class image:  # type = 2
+                        #                             class plat_image:
+                        #                                 url: str
+                        #                                 width: int
+                        #                                 height: int
+                        #                                 image_id: str
+                        #
+                        #                         class video:  # type = 3
+                        #                             class plat_video:
+                        #                                 class cover:
+                        #                                     url: str
+                        #                                     width: int
+                        #                                     height: int
+                        #
+                        #                                 url: str
+                        #                                 width: int
+                        #                                 height: int
+                        #                                 video_id: str
 
                         class url:  # type = 4
                             url: str
@@ -336,6 +344,27 @@ class Model:
         t: str
         event_id: str
 
+    class OPEN_FORUMS(event_class):
+        """
+        公域论坛事件的数据模型，可从t字段判断具体事件，其中包含：
+
+        - OPEN_FORUM_THREAD_CREATE - 当用户创建主题（帖子）时
+        - OPEN_FORUM_THREAD_UPDATE - 当用户更新主题（帖子）时
+        - OPEN_FORUM_THREAD_DELETE - 当用户删除主题（帖子）时
+
+        *剩余公域论坛事件（如回帖和回复回帖）暂未有相关推送*
+
+        .. seealso::
+             其子字段数据可参阅：
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#open-forums
+        """
+
+        guild_id: str
+        channel_id: str
+        author_id: str
+        t: str
+        event_id: str
+
     class AUDIO_ACTION(event_class):
         """
         音频事件的数据模型，可从t字段判断具体事件，其中包含：
@@ -352,6 +381,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#audio-action
         """
+
         channel_id: str
         guild_id: str
         audio_url: str
@@ -370,6 +400,7 @@ class Model:
              其子字段数据可参阅：
              https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#reaction
         """
+
         class emoji:
             id: str
             type: int
@@ -386,14 +417,22 @@ class Model:
 
     class INTERACTION(event_class):
         """
+        互动事件的数据模型，可从t字段判断具体事件，其中包含：
 
+        - INTERACTION_CREATE - 互动事件创建时
+
+        .. seealso::
+             其子字段数据可参阅：
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#interaction
         """
+
         class data:
             class resolved:
                 button_data: str
                 button_id: str
                 message_id: str
                 user_id: str
+
             type: int
 
         application_id: str
@@ -404,3 +443,22 @@ class Model:
         version: int
         t: str
         event_id: str
+
+    class LIVE_CHANNEL_MEMBER(event_class):
+        """
+        音视频/直播子频道成员进出事件的数据模型，可从t字段判断具体事件，其中包含：
+
+        - AUDIO_OR_LIVE_CHANNEL_MEMBER_ENTER - 当用户进入音视频/直播子频道
+        - AUDIO_OR_LIVE_CHANNEL_MEMBER_EXIT - 当用户离开音视频/直播子频道
+
+        .. seealso::
+             其子字段数据可参阅：
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#live_channel_member
+        """
+
+        channel_id: str
+        channel_type: int
+        guild_id: str
+        user_id: str
+        t: str
+        event_id: str
